// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('starter', ['ionic', 'starter.controllers', 'starter.services', 'ngCordova'])

.run(function($ionicPlatform, install) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
      cordova.plugins.Keyboard.disableScroll(true);

    }
    if (window.StatusBar) {
      // org.apache.cordova.statusbar required
      StatusBar.styleDefault();
    }
    document.addEventListener('deviceready', onDeviceReady, false);

    function onDeviceReady() {
      install.createDB();
    }

    install.initDir();
  });
})

.config(function($stateProvider, $urlRouterProvider, $ionicConfigProvider, $sceDelegateProvider) {
   $ionicConfigProvider.tabs.position('bottom');
  // Ionic uses AngularUI Router which uses the concept of states
  // Learn more here: https://github.com/angular-ui/ui-router
  // Set up the various states which the app can be in.
  // Each state's controller can be found in controllers.js
  $sceDelegateProvider.resourceUrlWhitelist([
    'self',
    'https://www.facebook.com/**'
  ]);
  $stateProvider

  // setup an abstract state for the tabs directive
    .state('tab', {
    url: '/tab',
    abstract: true,
    templateUrl: 'templates/tabs.html'
  })

  // Each tab has its own nav history stack:

  .state('tab.dash', {
    url: '/dash',
    views: {
      'tab-dash': {
        templateUrl: 'templates/tab-dash.html',
        controller: 'DashCtrl'
      }
    }
  })

  .state('tab.midia', {
      url: '/midia',
      views: {
        'tab-midia': {
          templateUrl: 'templates/tab-midia.html',
          controller: 'MidiaCtrl'
        }
      }
    })
    .state('tab.midia-for-categoria', {
      url: '/midia/:categoria',
      views: {
        'tab-midia': {
          templateUrl: 'templates/midia-for-categoria.html',
          controller: 'MidiaForCategoriaCtrl'
        }
      }
    })
    .state('tab.midia-details', {
      url: '/midia/details/:midiaId',
      views: {
        'tab-midia': {
          templateUrl: 'templates/midia-details.html',
          controller: 'MidiaDetailsCtrl'
        }
      }
    })

  .state('tab.equipe', {
    url: '/equipe',
    views: {
      'tab-equipe': {
        templateUrl: 'templates/tab-equipe.html',
        controller: 'EquipeCtrl'
      }
    }
  })
    .state('tab.equipe.all', {
      url: '/all',
      views: {
        'tab-equipe-all': {
          templateUrl: 'templates/tab-equipe-all.html',
          controller: 'EquipeAllCtrl'
        }
      }
    })
    .state('tab.equipe.all-details', {
      url: '/all/:id',
      views: {
        'tab-equipe-all': {
          templateUrl: 'templates/equipe-details.html',
          controller: 'EquipeDetailsCtrl'
        }
      }
    })
    .state('tab.equipe.convidados', {
      url: '/convidados',
      views: {
        'tab-convidados-all': {
          templateUrl: 'templates/tab-convidados-all.html',
          controller: 'ConvidadosAllCtrl'
        }
      }
    })
    .state('tab.equipe.convidados-details', {
      url: '/convidados/:id',
      views: {
        'tab-convidados-all': {
          templateUrl: 'templates/convidado-details.html',
          controller: 'ConvidadoDetailsCtrl'
        }
      }
    })

  .state('tab.boletins', {
    url: '/boletins',
    views: {
      'tab-boletins': {
        templateUrl: 'templates/tab-boletins.html',
        controller: 'BoletinsCtrl'
      }
    }
  })

  // if none of the above states are matched, use this as the fallback
  $urlRouterProvider.otherwise('/tab/dash');

}).directive('hideTabs', function($rootScope) {
  return {
      restrict: 'A',
      link: function($scope, $el) {
          $rootScope.hideTabs = 'tabs-item-hide';
          $scope.$on('$destroy', function() {
              $rootScope.hideTabs = 'show';
          });
      }
  };
});
